@@ -4,9 +4,9 @@ set -o errexit
 
 # ---------------UPDATE ME-------------------------------#
 # Increment me any time the environment should be rebuilt.
-# This includes dependncy changes, directory renames, etc.
-# Simple integer secuence: 1, 2, 3...
-environment_version=41
+# This includes dependency changes, directory renames, etc.
+# Simple integer sequence: 1, 2, 3...
+environment_version=45
 #--------------------------------------------------------#
 
 function usage {
@@ -27,17 +27,19 @@ function usage {
   echo "  -p, --pep8               Just run pep8"
   echo "  -t, --tabs               Check for tab characters in files."
   echo "  -y, --pylint             Just run pylint"
+  echo "  -j, --jshint             Just run jshint"
   echo "  -q, --quiet              Run non-interactively. (Relatively) quiet."
   echo "                           Implies -V if -N is not set."
   echo "  --only-selenium          Run only the Selenium unit tests"
   echo "  --with-selenium          Run unit tests including Selenium tests"
+  echo "  --selenium-headless      Run Selenium tests headless"
   echo "  --runserver              Run the Django development server for"
   echo "                           openstack_dashboard in the virtual"
   echo "                           environment."
   echo "  --docs                   Just build the documentation"
   echo "  --backup-environment     Make a backup of the environment on exit"
   echo "  --restore-environment    Restore the environment before running"
-  echo "  --destroy-environment    DEstroy the environment and exit"
+  echo "  --destroy-environment    Destroy the environment and exit"
   echo "  -h, --help               Print this usage message"
   echo ""
   echo "Note: with no options specified, the script will try to run the tests in"
@@ -63,12 +65,14 @@ just_pep8=0
 just_pylint=0
 just_docs=0
 just_tabs=0
+just_jshint=0
 never_venv=0
 quiet=0
 restore_env=0
 runserver=0
 only_selenium=0
 with_selenium=0
+selenium_headless=0
 testopts=""
 testargs=""
 with_coverage=0
@@ -76,6 +80,8 @@ makemessages=0
 compilemessages=0
 manage=0
 
+COVERAGE_CMD="python -m coverage.__main__"
+
 # Jenkins sets a "JOB_NAME" variable, if it's not set, we'll make it "default"
 [ "$JOB_NAME" ] || JOB_NAME="default"
 
@@ -92,6 +98,7 @@ function process_option {
     -N|--no-virtual-env) always_venv=0; never_venv=1;;
     -p|--pep8) just_pep8=1;;
     -y|--pylint) just_pylint=1;;
+    -j|--jshint) just_jshint=1;;
     -f|--force) force=1;;
     -t|--tabs) just_tabs=1;;
     -q|--quiet) quiet=1;;
@@ -101,6 +108,7 @@ function process_option {
     --compilemessages) compilemessages=1;;
     --only-selenium) only_selenium=1;;
     --with-selenium) with_selenium=1;;
+    --selenium-headless) selenium_headless=1;;
     --docs) just_docs=1;;
     --runserver) runserver=1;;
     --backup-environment) backup_env=1;;
@@ -135,6 +143,11 @@ function run_pylint {
   fi
 }
 
+function run_jshint {
+  echo "Running jshint ..."
+  jshint tuskar_ui/infrastructure/static/infrastructure
+}
+
 function run_pep8 {
   echo "Running flake8 ..."
   DJANGO_SETTINGS_MODULE=tuskar_ui.test.settings ${command_wrapper} flake8 $included_dirs
@@ -280,6 +293,10 @@ function run_tests {
     export SKIP_UNITTESTS=1
   fi
 
+  if [ $selenium_headless -eq 1 ]; then
+    export SELENIUM_HEADLESS=1
+  fi
+
   if [ -z "$testargs" ]; then
      run_tests_all
   else
@@ -298,21 +315,28 @@ function run_tests_all {
   if [ "$NOSE_WITH_HTML_OUTPUT" = '1' ]; then
     export NOSE_HTML_OUT_FILE='tuskar_ui_nose_results.html'
   fi
-  ${command_wrapper} coverage erase
-  ${command_wrapper} coverage run -p $root/manage.py test tuskar_ui --settings=tuskar_ui.test.settings $testopts
+  ${command_wrapper} ${COVERAGE_CMD} erase
+  ${command_wrapper} ${COVERAGE_CMD} run -p $root/manage.py test tuskar_ui --settings=tuskar_ui.test.settings $testopts
   # get results of the Horizon tests
   TUSKAR_UI_RESULT=$?
 
   if [ $with_coverage -eq 1 ]; then
     echo "Generating coverage reports"
-    ${command_wrapper} coverage combine
-    ${command_wrapper} coverage xml -i --omit='/usr*,setup.py,*egg*,.venv/*'
-    ${command_wrapper} coverage html -i --omit='/usr*,setup.py,*egg*,.venv/*' -d reports
+    ${command_wrapper} ${COVERAGE_CMD} combine
+    ${command_wrapper} ${COVERAGE_CMD} xml -i --omit='/usr*,setup.py,*egg*,.venv/*'
+    ${command_wrapper} ${COVERAGE_CMD} html -i --omit='/usr*,setup.py,*egg*,.venv/*' -d reports
   fi
   # Remove the leftover coverage files from the -p flag earlier.
   rm -f .coverage.*
 
-  if [ $(($TUSKAR_UI_RESULT)) -eq 0 ]; then
+  PEP8_RESULT=0
+  if [ $only_selenium -eq 0 ]; then
+    run_pep8
+    PEP8_RESULT=$?
+  fi
+
+  TEST_RESULT=$(($TUSKAR_UI_RESULT || $PEP8_RESULT))
+  if [ $TEST_RESULT -eq 0 ]; then
     echo "Tests completed successfully."
   else
     echo "Tests failed."
@@ -429,6 +453,12 @@ if [ $just_tabs -eq 1 ]; then
     exit $?
 fi
 
+# Jshint
+if [ $just_jshint -eq 1 ]; then
+    run_jshint
+    exit $?
+fi
+
 # Django development server
 if [ $runserver -eq 1 ]; then
     run_server
