@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -13,7 +12,6 @@
 #    under the License.
 
 from django.utils.translation import ugettext_lazy as _
-
 import horizon
 
 
@@ -21,8 +19,13 @@ class BasePanels(horizon.PanelGroup):
     slug = "infrastructure"
     name = _("Infrastructure")
     panels = (
+        'overview',
+        'parameters',
+        'roles',
         'nodes',
-        'overcloud',
+        'flavors',
+        'images',
+        'history',
     )
 
 
@@ -32,7 +35,7 @@ class Infrastructure(horizon.Dashboard):
     panels = (
         BasePanels,
     )
-    default_panel = 'overcloud'
+    default_panel = 'overview'
     permissions = ('openstack.roles.admin',)
 
 
