@@ -1,4 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
+# -*- coding: utf8 -*-
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,12 +12,21 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import defaults
+from django.conf import urls
 
 from tuskar_ui.infrastructure.overview import views
 
 
-urlpatterns = defaults.patterns(
+urlpatterns = urls.patterns(
     '',
-    defaults.url(r'^$', views.IndexView.as_view(), name='index'),
+    urls.url(r'^$', views.IndexView.as_view(), name='index'),
+    urls.url(r'^deploy-confirmation$',
+             views.DeployConfirmationView.as_view(),
+             name='deploy_confirmation'),
+    urls.url(r'^undeploy-confirmation$',
+             views.UndeployConfirmationView.as_view(),
+             name='undeploy_confirmation'),
+    urls.url(r'^post-deploy-init$',
+             views.PostDeployInitView.as_view(),
+             name='post_deploy_init'),
 )
