@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -16,7 +15,6 @@ import logging
 
 from django import template
 from django.utils import datastructures
-
 import horizon.workflows
 
 
@@ -30,7 +28,9 @@ class WorkflowView(horizon.workflows.WorkflowView):
 
 # FIXME: TableStep
 class TableStep(horizon.workflows.Step):
-    """A :class:`~horizon.workflows.Step` class which knows how to deal with
+    """A Step class with DataTables.
+
+    A :class:`~horizon.workflows.Step` class which knows how to deal with
     :class:`~horizon.tables.DataTable` classes rendered inside of it.
 
     This distinct class is required due to the complexity involved in handling
@@ -64,6 +64,7 @@ class TableStep(horizon.workflows.Step):
 
     def prepare_action_context(self, request, context):
         """Passes the tables to the action for validation and data extraction.
+
         """
         self.load_table_data()
         context['_tables'] = self._tables
@@ -83,7 +84,9 @@ class TableStep(horizon.workflows.Step):
         return step_template.render(context)
 
     def load_table_data(self):
-        """Calls the ``get_{{ table_name }}_data`` methods for each table class
+        """Sets table data.
+
+        Calls the ``get_{{ table_name }}_data`` methods for each table class
         and sets the data on the tables.
         """
         # We only want the data to be loaded once, so we track if we have...
@@ -103,7 +106,9 @@ class TableStep(horizon.workflows.Step):
             self._table_data_loaded = True
 
     def get_context_data(self, request):
-        """Adds a ``{{ table_name }}_table`` item to the context for each table
+        """Gets the table contexct data.
+
+        Adds a ``{{ table_name }}_table`` item to the context for each table
         in the :attr:`~horizon.tabs.TableTab.table_classes` attribute.
 
         If only one table class is provided, a shortcut ``table`` context
